Crate origen_metal
source ·Re-exports
pub extern crate cfg_if;pub extern crate config;pub extern crate lazy_static;pub use framework::sessions::sessions;pub use framework::sessions::Sessions;pub use framework::typed_value::Map as TypedValueMap;pub use framework::typed_value::TypedValue;pub use framework::typed_value::TypedValueVec;pub use frontend::with_frontend;pub use frontend::with_optional_frontend;pub use utils::file;pub use utils::outcome::Outcome;pub use utils::outcome::OutcomeState;pub use utils::outcome::OutcomeSubTypes;pub use utils::outcome::OutcomeSubtypes;pub use framework::users::users::add_user;pub use framework::users::users::clear_current_user;pub use framework::users::users::get_current_user_email;pub use framework::users::users::get_current_user_home_dir;pub use framework::users::users::get_current_user_id;pub use framework::users::users::get_initial_user_id;pub use framework::users::users::require_current_user_email;pub use framework::users::users::require_current_user_home_dir;pub use framework::users::users::require_current_user_id;pub use framework::users::users::set_current_user;pub use framework::users::users::try_lookup_and_set_current_user;pub use framework::users::users::try_lookup_current_user;pub use framework::users::users::users;pub use framework::users::users::users_mut;pub use framework::users::users::with_current_user;pub use framework::users::users::with_current_user_session;pub use framework::users::users::with_user;pub use framework::users::users::with_user_mut;pub use framework::users::users::with_users;pub use framework::users::users::with_users_mut;pub use framework::users::users::with_user_or_current;pub use framework::users::user::add_dataset_to_user;pub use framework::users::user::register_dataset_with_user;pub use framework::users::user::with_user_dataset;pub use framework::users::user::with_user_dataset_mut;pub use framework::users::user::with_user_hierarchy;pub use framework::users::user::with_user_motive_or_default;pub use framework::users::users::unload as unload_users;pub use utils::os::on_linux as running_on_linux;pub use utils::os::on_windows as running_on_windows;
Modules
- The framework module contains functionality that is closely related to implementing a a particular framework feature. While still generic in nature, they are not so low-level as the functions found in the utils module which could be used in a variety of different contexts. The functionality in this module assumes that it will be used to implement something very similar to Origen’s implementation of the given feature.
Macros
- Get the caller name. Taken from this SO answer: https://stackoverflow.com/a/63904992/8533619
- Exit the origen process with a failing exit code and a big ERROR banner
- Exit the origen process with a failing exit code and a big FAIL banner
- Exit the origen process with a passing exit code and a big PASS banner
- Exit the origen process with a passing exit code and a big SUCCESS banner